=================
PyTables Cookbook
=================

.. this document includes contents coming from the UserDocuments section of
   wiki (http://www.pytables.org/moin/UserDocuments) and from the
   HintsForSQLUsers page (http://www.pytables.org/moin/HintsForSQLUsers).


--------
Contents
--------

.. toctree::
    :maxdepth: 1

    hints_for_sql_users
    PyTables & py2exe Howto (by Tommy Edvardsen) <py2exe_howto>
    How to install PyTables when you're not root (by Koen van de Sande) <no_root_install>
    tailoring_atexit_hooks
    custom_data_types
    simple_table
    inmemory_hdf5_files
